pub fn canonical_bytes(doc: &Attestation) -> Vec<u8> ⓘExpand description
Canonical serialization of an attestation for signing: the JSON with the signature field removed, keys emitted in sorted order.
pub fn canonical_bytes(doc: &Attestation) -> Vec<u8> ⓘCanonical serialization of an attestation for signing: the JSON with the signature field removed, keys emitted in sorted order.